@@ -30,7 +30,6 @@ from .lstcontainers import (
     ThrownEventsHistogram,
 )
 
-
 log = logging.getLogger(__name__)
 
 __all__ = [
@@ -41,6 +40,7 @@ __all__ = [
     'auto_merge_h5files',
     'check_mcheader',
     'check_metadata',
+    'check_mc_type',
     'check_thrown_events_histogram',
     'copy_h5_nodes',
     'extract_simulation_nsb',
@@ -80,6 +80,8 @@ dl1_images_lstcam_key = "/dl1/event/telescope/image/LST_LSTCam"
 dl2_params_lstcam_key = "/dl2/event/telescope/parameters/LST_LSTCam"
 dl1_params_src_dep_lstcam_key = "/dl1/event/telescope/parameters_src_dependent/LST_LSTCam"
 dl2_params_src_dep_lstcam_key = "/dl2/event/telescope/parameters_src_dependent/LST_LSTCam"
+dl1_likelihood_params_lstcam_key = "/dl1/event/telescope/likelihood_parameters/LST_LSTCam"
+dl2_likelihood_params_lstcam_key = "/dl2/event/telescope/likelihood_parameters/LST_LSTCam"
 
 HDF5_ZSTD_FILTERS = tables.Filters(
     complevel=5,  # enable compression, 5 is a good tradeoff between compression and speed
@@ -527,7 +529,7 @@ def check_mcheader(mcheader1, mcheader2):
         v1 = mcheader1[k]
         v2 = mcheader2[k]
         if v1 != v2:
-            raise ValueError('MC headers do not match for key {k}:  {v1!r} / {v2!r}')
+            raise ValueError(f'MC headers do not match for key {k}:  {v1!r} / {v2!r}')
 
 
 def check_thrown_events_histogram(thrown_events_hist1, thrown_events_hist2):
@@ -612,7 +614,7 @@ def check_metadata(metadata1, metadata2):
         v1 = metadata1[k]
         v2 = metadata2[k]
         if v1 != v2:
-            raise ValueError('Metadata does not match for key {k}:  {v1!r} / {v2!r}')
+            raise ValueError(f'Metadata does not match for key {k}:  {v1!r} / {v2!r}')
 
 
 def global_metadata():
@@ -856,7 +858,7 @@ def read_mc_dl2_to_QTable(filename):
     -------
     `astropy.table.QTable`, `pyirf.simulations.SimulatedEventsInfo`
     """
-    
+
     # mapping
     name_mapping = {
         "mc_energy": "true_energy",
@@ -880,7 +882,7 @@ def read_mc_dl2_to_QTable(filename):
 
     # add alpha for source-dependent analysis
     srcdep_flag = dl2_params_src_dep_lstcam_key in get_dataset_keys(filename)
-    
+
     if srcdep_flag:
         unit_mapping['alpha'] = u.deg
 
@@ -940,7 +942,7 @@ def read_data_dl2_to_QTable(filename, srcdep_pos=None):
 
     # add alpha for source-dependent analysis
     srcdep_flag = dl2_params_src_dep_lstcam_key in get_dataset_keys(filename)
-    
+
     if srcdep_flag:
         unit_mapping['alpha'] = u.deg
 
@@ -1131,3 +1133,34 @@ def extract_simulation_nsb(filename):
                     print('Unexpected end of %s,\n caught exception %s', filename, e)
     return nsb
 
+
+def check_mc_type(filename):
+    """
+    Check MC type ('point_like', 'diffuse', 'ring_wobble') based on the viewcone setting
+    Parameters
+    ----------
+    filename:path (DL1/DL2 hdf file)
+    Returns
+    -------
+    string
+    """
+
+    simu_info = read_simu_info_merged_hdf5(filename)
+    
+    min_viewcone = simu_info.min_viewcone_radius.value
+    max_viewcone = simu_info.max_viewcone_radius.value
+
+    if max_viewcone == 0.0:
+        mc_type = 'point_like'
+
+    elif min_viewcone == 0.0:
+        mc_type = 'diffuse'
+        
+    elif (max_viewcone - min_viewcone) < 0.1:
+        mc_type = 'ring_wobble'
+
+    else:
+        raise ValueError('mc type cannot be identified')
+
+    return mc_type
+            
