@@ -102,7 +102,7 @@ optional.add_argument(
 
 
 def main():
-    args = parser.parse_args()
+    args, remaining_args = parser.parse_known_args()
     run = args.run_number
     prod_id = args.prod_version
     stat_events = args.statistics
@@ -237,6 +237,7 @@ def main():
         f"--config={config_file}",
         f"--log-file={log_file}",
         "--log-file-level=DEBUG",
+        *remaining_args,
     ]
 
     print("\n--> RUNNING...")
