@@ -53,7 +53,7 @@ parser.add_argument(
 
 
 def main():
-    args = parser.parse_known_args()
+    args, remaining_args = parser.parse_known_args()
     run = args.run_number
     prod_id = args.prod_version
     max_events = args.max_events
@@ -112,6 +112,8 @@ def main():
     if args.no_progress:
         cmd.append("--no-progress")
 
+    cmd.extend(remaining_args)
+
     subprocess.run(cmd, check=True)
 
     # plot and save some results
