@@ -267,21 +267,28 @@ def test_merge_datacheck_files(temp_dir_observed_files):
 
 
 def test_lstchain_merged_dl1_to_dl2(
-    temp_dir_simulated_files, merged_simulated_dl1_file, rf_models
+    temp_dir_simulated_files, simulated_dl1_file, merged_simulated_dl1_file, rf_models
 ):
-    output_file = merged_simulated_dl1_file.with_name(
+    simulated_dl1_file_ = simulated_dl1_file.parent.joinpath('another_dl1.h5')
+    simulated_dl1_file_.symlink_to(simulated_dl1_file)
+    output_file_1 = simulated_dl1_file_.with_name(
+        simulated_dl1_file_.name.replace("dl1", "dl2")
+    )
+    output_file_2 = merged_simulated_dl1_file.with_name(
         merged_simulated_dl1_file.name.replace("dl1", "dl2")
     )
     run_program(
         "lstchain_dl1_to_dl2",
         "-f",
+        simulated_dl1_file_,
         merged_simulated_dl1_file,
         "-p",
         rf_models["path"],
         "--output-dir",
         temp_dir_simulated_files,
     )
-    assert output_file.is_file()
+    assert output_file_1.is_file()
+    assert output_file_2.is_file()
 
 
 def test_lstchain_dl1_to_dl2(simulated_dl2_file):
