@@ -139,7 +139,9 @@ def test_create_irf_point_like_energy_dependent_cuts(
                 "--overwrite",
                 "--energy-dependent-gh",
                 "--point-like",
-                "--energy-dependent-theta"
+                "--energy-dependent-theta",
+                "--DL3Cuts.max_theta_cut=1",
+                "--DL3Cuts.fill_theta_cut=1"
             ],
             cwd=temp_dir_observed_files,
         )
@@ -148,7 +150,41 @@ def test_create_irf_point_like_energy_dependent_cuts(
 
     assert RadMax2D.read(irf_file, hdu="RAD_MAX")
 
+def test_create_irf_point_like_srcdep_energy_dependent_cuts(
+    temp_dir_observed_srcdep_files, simulated_srcdep_dl2_file
+):
+    """
+    Generating point-like source-dependent IRF file from a test DL2 files,
+    using energy-dependent cuts
+    """
+    from lstchain.tools.lstchain_create_irf_files import IRFFITSWriter
+    from astropy.table import QTable
 
+    irf_file = temp_dir_observed_srcdep_files / "irf_edep.fits.gz"
+    
+    assert (
+        run_tool(
+            IRFFITSWriter(),
+            argv=[
+                f"--input-gamma-dl2={simulated_srcdep_dl2_file}",
+                f"--output-irf-file={irf_file}",
+                "--point-like",
+                "--source-dep",
+                "--energy-dependent-gh",
+                "--energy-dependent-alpha",
+                "--overwrite",
+            ],
+            cwd=temp_dir_observed_srcdep_files,
+       )
+       == 0
+    )
+    
+    gh_cuts = QTable.read(irf_file, hdu="GH_CUTS")
+    assert isinstance(gh_cuts.meta["GH_EFF"], float)
+    
+    al_cuts = QTable.read(irf_file, hdu="AL_CUTS")
+    assert isinstance(al_cuts.meta["AL_CONT"], float)
+    
 @pytest.mark.private_data
 def test_create_dl3_energy_dependent_cuts(
     temp_dir_observed_files, observed_dl2_file
@@ -164,7 +200,7 @@ def test_create_dl3_energy_dependent_cuts(
 
     dl2_name = observed_dl2_file.name
     observed_dl3_file = temp_dir_observed_files / dl2_name.replace('dl2', 'dl3')
-    observed_dl3_file = observed_dl3_file.with_suffix(".fits.gz")
+    observed_dl3_file = observed_dl3_file.with_suffix(".fits")
 
     assert (
         run_tool(
@@ -244,7 +280,9 @@ def test_create_dl3_with_config(temp_dir_observed_files, observed_dl2_file):
 
 
 @pytest.mark.private_data
-def test_create_srcdep_dl3(temp_dir_observed_srcdep_files, observed_srcdep_dl2_file, simulated_srcdep_irf_file):
+def test_create_srcdep_dl3(
+        temp_dir_observed_srcdep_files, observed_srcdep_dl2_file, simulated_srcdep_irf_file
+):
     """
     Generating a source-dependent DL3 file from a test DL2 files and test IRF file
     """
@@ -278,6 +316,37 @@ def test_create_srcdep_dl3(temp_dir_observed_srcdep_files, observed_srcdep_dl2_f
     np.testing.assert_allclose(ra, 83.63, atol=1e-2)
     np.testing.assert_allclose(dec, 22.01, atol=1e-2)
 
+@pytest.mark.private_data
+def test_create_srcdep_dl3_energy_dependent_cuts(
+        temp_dir_observed_srcdep_files, observed_srcdep_dl2_file
+):
+    """
+    Generating a source-dependent DL3 file from a test DL2 files and test IRF file,
+    using energy-dependent cuts
+    """
+    from lstchain.tools.lstchain_create_dl3_file import DataReductionFITSWriter
+
+    irf_file = temp_dir_observed_srcdep_files / "irf_edep.fits.gz"
+
+    assert (
+        run_tool(
+            DataReductionFITSWriter(),
+            argv=[
+                f"--input-dl2={observed_srcdep_dl2_file}",
+                f"--output-dl3-path={temp_dir_observed_srcdep_files}",
+                f"--input-irf={irf_file}",
+                "--source-name=Crab",
+                "--source-ra=83.633deg",
+                "--source-dec=22.01deg",
+                "--source-dep",
+                "--overwrite",
+            ],
+            cwd=temp_dir_observed_srcdep_files,
+        )
+        == 0
+    )
+
+
 @pytest.mark.private_data
 def test_index_dl3_files(temp_dir_observed_files):
     """
