@@ -1,13 +1,14 @@
 import astropy.units as u
 import numpy as np
+import matplotlib.pyplot as plt
 from ctapipe.instrument import CameraGeometry
 from ctapipe.visualization import CameraDisplay
 
 from lstchain.reco.disp import disp_parameters_event
 from lstchain.visualization.camera import overlay_source, overlay_disp_vector, display_dl1_event
 
-
 def test_overlay_source():
+    plt.figure()
     geom = CameraGeometry.from_name('LSTCam')
     image = np.random.rand(geom.n_pixels)
     display = CameraDisplay(geom, image)
@@ -15,6 +16,7 @@ def test_overlay_source():
 
 
 def test_overlay_disp_vector():
+    plt.figure()
     from ctapipe.image import hillas_parameters
 
     geom = CameraGeometry.from_name('LSTCam')
@@ -33,5 +35,6 @@ def test_display_dl1_event(mc_gamma_testfile):
     seeker = EventSeeker(source)
     event = seeker.get_event_index(11)  # event 11 has telescopes 1 and 4 with data
     CameraCalibrator(subarray=source.subarray)(event)
+    plt.figure()
     display_dl1_event(event, source.subarray.tel[1].camera.geometry, tel_id=1)
     display_dl1_event(event, source.subarray.tel[4].camera.geometry, tel_id=4)
